@@ -18,7 +18,7 @@ std::string PosixRegex::getErrorMessage(int result) const
 	return msg.c_str();
 }
 
-PosixRegex::PosixRegex(std::string const & regex, int cflags) throw(Exception)
+PosixRegex::PosixRegex(std::string const & regex, int cflags)
 {
 	int result(::regcomp(&preg_, regex.c_str(), cflags));
 	if (result != 0)
@@ -34,7 +34,7 @@ PosixRegex::~PosixRegex()
 	::regfree(&preg_);
 }
 
-PosixRegex::Match PosixRegex::runMatch(std::string const & text, int eflags) throw(Exception)
+PosixRegex::Match PosixRegex::runMatch(std::string const & text, int eflags)
 {
 	Match result;
 	::regmatch_t pmatch[1];
@@ -56,7 +56,7 @@ PosixRegex::Match PosixRegex::runMatch(std::string const & text, int eflags) thr
 	return result;
 }
 
-bool PosixRegex::run(std::string const & text, int eflags) throw(Exception)
+bool PosixRegex::run(std::string const & text, int eflags)
 {
 	return runMatch(text, eflags).matches;
 }
