@@ -10,7 +10,7 @@
 #include <idna.h>
 
 // C++ libraries
-#include <cc++/url.h>
+#include <ucommon/string.h>
 
 // Local
 #include "auto_ptr_compat.hpp"
@@ -377,13 +377,15 @@ Conversion const * Cpp2Base64Converter::make(char const * const buf, size_t cons
 	{
 		long lDestSize((bufSize+2) / 3*4 + 1);
 		dest = (char*) Sys::malloc(lDestSize);
-		destSize = ost::b64Encode((const unsigned char *)buf, bufSize, dest, lDestSize);
+		ucommon::String::b64encode(dest, (const unsigned char *)buf, bufSize, lDestSize);
+		destSize = lDestSize-1;
 	}
 	else
 	{
 		long lDestSize(bufSize / 4*3 + 1);
 		dest = (char*) Sys::malloc(lDestSize);
-		destSize = ost::b64Decode(buf, (unsigned char *)dest, lDestSize);
+		ucommon::String::b64decode((unsigned char *)dest, buf, lDestSize);
+		destSize = lDestSize-1;
 	}
 	return new StdFreeConversion(dest, destSize);
 }
